@@ -215,6 +215,9 @@ pub struct PanelUi {
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct GeneralConfig {
+    #[serde(default)]
+    pub disable_debug_error_mode: bool,
+
     #[serde(default)]
     pub enable_mouse: bool,
 
@@ -227,6 +230,9 @@ pub struct GeneralConfig {
     #[serde(default)]
     pub enable_recover_mode: bool,
 
+    #[serde(default)]
+    pub hide_remaps_in_help_menu: bool,
+
     #[serde(default)]
     pub prompt: UiElement,
 
@@ -517,6 +523,9 @@ pub struct BuiltinModesConfig {
     #[serde(default)]
     pub default: Mode,
 
+    #[serde(default)]
+    pub debug_error: Mode,
+
     #[serde(default)]
     pub recover: Mode,
 
@@ -573,6 +582,7 @@ impl BuiltinModesConfig {
     pub fn get(&self, name: &str) -> Option<&Mode> {
         match name {
             "default" => Some(&self.default),
+            "debug_error" => Some(&self.debug_error),
             "recover" => Some(&self.recover),
             "selection ops" => Some(&self.selection_ops),
             "selection_ops" => Some(&self.selection_ops),
