@@ -1,15 +1,29 @@
 use crate::app::VERSION;
 use crate::config::Config;
 use anyhow::bail;
+use anyhow::Error;
 use anyhow::Result;
 use mlua::Lua;
 use mlua::LuaSerdeExt;
+use mlua::SerializeOptions;
 use serde::Deserialize;
+use serde::Serialize;
 use std::fs;
 
 const DEFAULT_LUA_SCRIPT: &str = include_str!("init.lua");
 const UPGRADE_GUIDE_LINK: &str = "https://xplr.dev/en/upgrade-guide.html";
 
+pub fn serialize<'lua, T: Serialize + Sized>(
+    lua: &'lua mlua::Lua,
+    value: &T,
+) -> Result<mlua::Value<'lua>> {
+    lua.to_value_with(
+        value,
+        SerializeOptions::new().serialize_none_to_null(false),
+    )
+    .map_err(Error::from)
+}
+
 fn parse_version(version: &str) -> Result<(u16, u16, u16, Option<u16>)> {
     let mut configv = version.split('.');
 
@@ -49,37 +63,13 @@ pub fn check_version(version: &str, path: &str) -> Result<()> {
     }
 }
 
-fn resolve_fn_recursive<'lua, 'a>(
-    table: &mlua::Table<'lua>,
-    mut path: impl Iterator<Item = &'a str>,
-) -> Result<mlua::Function<'lua>> {
-    if let Some(nxt) = path.next() {
-        match table.get(nxt)? {
-            mlua::Value::Table(t) => resolve_fn_recursive(&t, path),
-            mlua::Value::Function(f) => Ok(f),
-            t => bail!("{:?} is not a function", t),
-        }
-    } else {
-        bail!("Invalid path")
-    }
-}
-
-/// This function resolves paths like `builtin.func_foo`, `custom.func_bar` into lua functions.
-pub fn resolve_fn<'lua>(
-    globals: &mlua::Table<'lua>,
-    path: &str,
-) -> Result<mlua::Function<'lua>> {
-    let path = format!("xplr.fn.{}", path);
-    resolve_fn_recursive(globals, path.split('.'))
-}
-
 /// Used to initialize Lua globals
 pub fn init(lua: &Lua) -> Result<Config> {
     let config = Config::default();
     let globals = lua.globals();
 
     let lua_xplr = lua.create_table()?;
-    lua_xplr.set("config", lua.to_value(&config)?)?;
+    lua_xplr.set("config", serialize(lua, &config)?)?;
 
     let lua_xplr_fn = lua.create_table()?;
     let lua_xplr_fn_builtin = lua.create_table()?;
@@ -119,14 +109,37 @@ pub fn extend(lua: &Lua, path: &str) -> Result<Config> {
     Ok(config)
 }
 
-/// Used to call lua functions.
+fn resolve_fn_recursive<'lua, 'a>(
+    table: &mlua::Table<'lua>,
+    mut path: impl Iterator<Item = &'a str>,
+) -> Result<mlua::Function<'lua>> {
+    if let Some(nxt) = path.next() {
+        match table.get(nxt)? {
+            mlua::Value::Table(t) => resolve_fn_recursive(&t, path),
+            mlua::Value::Function(f) => Ok(f),
+            t => bail!("{:?} is not a function", t),
+        }
+    } else {
+        bail!("Invalid path")
+    }
+}
+
+/// This function resolves paths like `builtin.func_foo`, `custom.func_bar` into lua functions.
+pub fn resolve_fn<'lua>(
+    globals: &mlua::Table<'lua>,
+    path: &str,
+) -> Result<mlua::Function<'lua>> {
+    resolve_fn_recursive(globals, path.split('.'))
+}
+
 pub fn call<'lua, R: Deserialize<'lua>>(
     lua: &'lua Lua,
     func: &str,
-    args: mlua::Value<'lua>,
+    arg: mlua::Value<'lua>,
 ) -> Result<R> {
-    let func = resolve_fn(&lua.globals(), func)?;
-    let res: mlua::Value = func.call(args)?;
+    let func = format!("xplr.fn.{}", func);
+    let func = resolve_fn(&lua.globals(), &func)?;
+    let res: mlua::Value = func.call(arg)?;
     let res: R = lua.from_value(res)?;
     Ok(res)
 }
@@ -141,24 +154,24 @@ mod tests {
         assert!(check_version(VERSION, "foo path").is_ok());
 
         // Current release if OK
-        assert!(check_version("0.16.2", "foo path").is_ok());
+        assert!(check_version("0.17.1", "foo path").is_ok());
 
         // Prev major release is ERR
         // - Not yet
 
         // Prev minor release is ERR (Change when we get to v1)
-        assert!(check_version("0.15.2", "foo path").is_err());
+        assert!(check_version("0.16.1", "foo path").is_err());
 
         // Prev bugfix release is OK
-        assert!(check_version("0.16.1", "foo path").is_ok());
+        assert!(check_version("0.17.0", "foo path").is_ok());
 
         // Next major release is ERR
-        assert!(check_version("1.16.2", "foo path").is_err());
+        assert!(check_version("1.17.1", "foo path").is_err());
 
         // Next minor release is ERR
-        assert!(check_version("0.17.2", "foo path").is_err());
+        assert!(check_version("0.18.1", "foo path").is_err());
 
         // Next bugfix release is ERR (Change when we get to v1)
-        assert!(check_version("0.16.3", "foo path").is_err());
+        assert!(check_version("0.17.2", "foo path").is_err());
     }
 }
